Index: include/asterisk/sched.h
===================================================================
RCS file: /usr/cvsroot/asterisk/include/asterisk/sched.h,v
retrieving revision 1.3
diff -u -r1.3 sched.h
--- include/asterisk/sched.h	6 Nov 2001 17:33:30 -0000	1.3
+++ include/asterisk/sched.h	13 Apr 2005 12:20:09 -0000
@@ -102,6 +102,14 @@
  */
 extern void ast_sched_dump(struct sched_context *con);
 
+/*!Returns the number of seconds before an event takes place */
+/*!
+ * \param con Context to use
+ * \param id Id to dump
+ */
+extern long ast_sched_when(struct sched_context *con,int id);
+
+
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
Index: sched.c
===================================================================
RCS file: /usr/cvsroot/asterisk/sched.c,v
retrieving revision 1.14
diff -u -r1.14 sched.c
--- sched.c	20 Jul 2004 13:43:33 -0000	1.14
+++ sched.c	13 Apr 2005 12:20:09 -0000
@@ -399,3 +399,28 @@
 	ast_mutex_unlock(&con->lock);
 	return x;
 }
+
+long ast_sched_when(struct sched_context *con,int id)
+{
+	struct sched *s;
+	long secs;
+	struct timeval now;
+	DEBUG(ast_log(LOG_DEBUG, "ast_sched_when()\n"));
+
+	ast_mutex_lock(&con->lock);
+	s=con->schedq;
+	while (s!=NULL) {
+		if (s->id==id) break;
+		s=s->next;
+	}
+	secs=-1;
+	if (s!=NULL) {
+		if (gettimeofday(&now, NULL)) {
+			ast_log(LOG_NOTICE, "gettimeofday() failed!\n");
+		} else {
+			secs=s->when.tv_sec-now.tv_sec;
+		}
+	}
+	ast_mutex_unlock(&con->lock);
+	return secs;
+}
Index: channels/chan_sip.c
===================================================================
RCS file: /usr/cvsroot/asterisk/channels/chan_sip.c,v
retrieving revision 1.510.2.54
diff -u -r1.510.2.54 chan_sip.c
--- channels/chan_sip.c	2 Mar 2005 17:38:27 -0000	1.510.2.54
+++ channels/chan_sip.c	13 Apr 2005 12:20:11 -0000
@@ -603,6 +603,7 @@
 {
 	int res;
 	char iabuf[INET_ADDRSTRLEN];
+// ast_log(LOG_WARNING, "__sip_xmit from '%s' to '%s'\n", "", ast_inet_ntoa(iabuf, sizeof(iabuf), p->recv.sin_addr));
 	if (p->nat & SIP_NAT_ROUTE)
 	    res=sendto(sipsock, data, len, 0, (struct sockaddr *)&p->recv, sizeof(struct sockaddr_in));
 	else
@@ -5798,7 +5799,7 @@
 		ast_cli(fd, "  Mailbox      : %s\n", peer->mailbox);
 		ast_cli(fd, "  LastMsgsSent : %d\n", peer->lastmsgssent);
 		ast_cli(fd, "  Dynamic      : %s\n", (peer->dynamic?"Yes":"No"));
-		ast_cli(fd, "  Expire       : %d\n", peer->expire);
+		ast_cli(fd, "  Expire       : %ld seconds\n", ast_sched_when(sched,peer->expire));
 		ast_cli(fd, "  Expiry       : %d\n", peer->expiry);
 		ast_cli(fd, "  Insecure     : %s\n", (peer->insecure?((peer->insecure == 2)?"Very":"Yes"):"No") );
 		ast_cli(fd, "  Nat          : %s\n", nat2str(peer->nat));
